// -------------------------------------------------------------------------------------
// refinements
// -------------------------------------------------------------------------------------
/**
 * @category refinements
 * @since 3.0.0
 */
export const isString = (u) => typeof u === 'string';
// -------------------------------------------------------------------------------------
// instances
// -------------------------------------------------------------------------------------
/**
 * @category instances
 * @since 3.0.0
 */
export const Eq = {
    equals: (second) => (first) => first === second
};
/**
 * `string` semigroup under concatenation.
 *
 * @example
 * import { Semigroup } from 'fp-ts/string'
 * import { pipe } from 'fp-ts/function'
 *
 * assert.deepStrictEqual(pipe('a', Semigroup.concat('b')), 'ab')
 *
 * @category instances
 * @since 3.0.0
 */
export const Semigroup = {
    concat: (second) => (first) => first + second
};
/**
 * An empty `string`.
 *
 * @since 3.0.0
 */
export const empty = '';
/**
 * `string` monoid under concatenation.
 *
 * The `empty` value is `''`.
 *
 * @example
 * import { Monoid } from 'fp-ts/string'
 * import { pipe } from 'fp-ts/function'
 *
 * assert.deepStrictEqual(pipe('a', Monoid.concat('b')), 'ab')
 *
 * @category instances
 * @since 3.0.0
 */
export const Monoid = {
    concat: Semigroup.concat,
    empty
};
/**
 * @category instances
 * @since 3.0.0
 */
export const Ord = {
    compare: (second) => (first) => (first < second ? -1 : first > second ? 1 : 0)
};
/**
 * @category instances
 * @since 3.0.0
 */
export const Show = {
    show: (a) => JSON.stringify(a)
};
// -------------------------------------------------------------------------------------
// utils
// -------------------------------------------------------------------------------------
/**
 * Test whether a `string` is empty.
 *
 * @since 3.0.0
 */
export const isEmpty = (s) => s.length === 0;
/**
 * Calculate the number of characters in a `string`.
 *
 * @since 3.0.0
 */
export const size = (s) => s.length;
/**
 * @since 3.0.0
 */
export const toUpperCase = (s) => s.toUpperCase();
